//
// Syd: rock-solid unikernel
// src/syd-check.rs: View syd logs using journalctl.
//
// Copyright (c) 2024 Ali Polatel <alip@chesswob.org>
//
// SPDX-License-Identifier: GPL-3.0-or-later

use std::{
    os::unix::process::CommandExt,
    process::{Command, ExitCode},
};

// Set global allocator to mimalloc if mimalloc feature is enabled (default).
#[cfg(feature = "mimalloc")]
#[global_allocator]
static GLOBAL: mimalloc2_rust::GlobalMiMalloc = mimalloc2_rust::GlobalMiMalloc;

fn main() -> ExitCode {
    // Configure mimalloc.
    syd::configure_mimalloc();

    #[allow(clippy::disallowed_methods)]
    syd::set_sigpipe_dfl().expect("SIGPIPE");

    Command::new("journalctl")
        .arg("SYSLOG_IDENTIFIER=syd")
        .exec();
    ExitCode::FAILURE
}
